pub struct FinalizedBlock {
pub(crate) block: Arc<Block>,
pub(crate) hash: Hash,
pub(crate) height: Height,
pub(crate) new_outputs: HashMap<OutPoint, OrderedUtxo>,
pub(crate) transaction_hashes: Arc<[Hash]>,
pub(crate) treestate: Treestate,
pub(crate) deferred_pool_balance_change: Option<DeferredPoolBalanceChange>,
}Expand description
Contains a block with all its associated data that the finalized state can commit to its database.
Note that it’s the constructor’s responsibility to ensure that all data is valid and verified.
Fields
block: Arc<Block>The block to commit to the state.
hash: HashThe hash of the block.
height: HeightThe height of the block.
new_outputs: HashMap<OutPoint, OrderedUtxo>New transparent outputs created in this block, indexed by
OutPoint.
transaction_hashes: Arc<[Hash]>A precomputed list of the hashes of the transactions in this block, in the same order as
block.transactions.
treestate: TreestateThe tresstate associated with the block.
deferred_pool_balance_change: Option<DeferredPoolBalanceChange>This block’s deferred pool value balance change.
Implementations
Sourceimpl FinalizedBlock
impl FinalizedBlock
Sourcepub fn from_checkpoint_verified(
block: CheckpointVerifiedBlock,
treestate: Treestate,
) -> Self
pub fn from_checkpoint_verified( block: CheckpointVerifiedBlock, treestate: Treestate, ) -> Self
Constructs FinalizedBlock from CheckpointVerifiedBlock and its Treestate.
Sourcepub fn from_contextually_verified(
block: ContextuallyVerifiedBlock,
treestate: Treestate,
) -> Self
pub fn from_contextually_verified( block: ContextuallyVerifiedBlock, treestate: Treestate, ) -> Self
Constructs FinalizedBlock from ContextuallyVerifiedBlock and its Treestate.
Sourcefn from_semantically_verified(
block: SemanticallyVerifiedBlock,
treestate: Treestate,
) -> Self
fn from_semantically_verified( block: SemanticallyVerifiedBlock, treestate: Treestate, ) -> Self
Constructs FinalizedBlock from SemanticallyVerifiedBlock and its Treestate.