pub struct SemanticallyVerifiedBlock {
pub block: Arc<Block>,
pub hash: Hash,
pub height: Height,
pub new_outputs: HashMap<OutPoint, OrderedUtxo>,
pub transaction_hashes: Arc<[Hash]>,
pub deferred_pool_balance_change: Option<DeferredPoolBalanceChange>,
}Expand description
A block which has undergone semantic validation and has been prepared for contextual validation.
It is the constructor’s responsibility to perform semantic validation and to ensure that all fields are consistent.
This structure contains data from contextual validation, which is computed in the service caller’s task, not inside the service call itself. This allows moving work out of the single-threaded state service.
Fields
block: Arc<Block>The block to commit to the state.
hash: HashThe hash of the block.
height: HeightThe height of the block.
new_outputs: HashMap<OutPoint, OrderedUtxo>New transparent outputs created in this block, indexed by
OutPoint.
Each output is tagged with its transaction index in the block. (The outputs of earlier transactions in a block can be spent by later transactions.)
Note: although these transparent outputs are newly created, they may not be unspent, since a later transaction in a block can spend outputs of an earlier transaction.
This field can also contain unrelated outputs, which are ignored.
transaction_hashes: Arc<[Hash]>A precomputed list of the hashes of the transactions in this block,
in the same order as block.transactions.
deferred_pool_balance_change: Option<DeferredPoolBalanceChange>This block’s deferred pool value balance change.
Implementations
Sourceimpl SemanticallyVerifiedBlock
impl SemanticallyVerifiedBlock
Sourcepub fn with_hash(block: Arc<Block>, hash: Hash) -> Self
pub fn with_hash(block: Arc<Block>, hash: Hash) -> Self
Creates SemanticallyVerifiedBlock from Block and block::Hash.
Sourcepub fn with_deferred_pool_balance_change(
self,
deferred_pool_balance_change: Option<DeferredPoolBalanceChange>,
) -> Self
pub fn with_deferred_pool_balance_change( self, deferred_pool_balance_change: Option<DeferredPoolBalanceChange>, ) -> Self
Sets the deferred balance in the block.